package com.sun.jmx.snmp.agent;

import com.sun.jmx.snmp.SnmpVarBind;
import java.util.Vector;
import com.sun.jmx.snmp.SnmpStatusException;
import java.util.Hashtable;
import java.io.Serializable;

public abstract class SnmpMibGroup extends SnmpMibOid implements Serializable
{
    protected Hashtable<Long, Long> subgroups;
    
    public SnmpMibGroup() {
        this.subgroups = null;
    }
    
    public abstract boolean isTable(long p0);
    
    public abstract boolean isVariable(long p0);
    
    public abstract boolean isReadable(long p0);
    
    public abstract SnmpMibTable getTable(long p0);
    
    public void validateVarId(long n, Object o) throws SnmpStatusException {
        if (!this.isVariable(n)) {
            throw new SnmpStatusException(225);
        }
        return;
    }
    
    public boolean isNestedArc(long value) {
        return this.subgroups != null && this.subgroups.get(new Long(value)) != null;
    }
    
    @Override
    public abstract void get(SnmpMibSubRequest p0, int p1) throws SnmpStatusException;
    
    @Override
    public abstract void set(SnmpMibSubRequest p0, int p1) throws SnmpStatusException;
    
    @Override
    public abstract void check(SnmpMibSubRequest p0, int p1) throws SnmpStatusException;
    
    @Override
    public void getRootOid(Vector<Integer> vector) {
    }
    
    void registerNestedArc(long value) {
        Long n = new Long(value);
        if (this.subgroups == null) {
            this.subgroups = new Hashtable();
        }
        this.subgroups.put(n, n);
    }
    
    protected void registerObject(long n) throws IllegalAccessException {
        super.registerNode(new long[] { n }, 0, null);
    }
    
    @Override
    void registerNode(long[] array, int n, SnmpMibNode snmpMibNode) throws IllegalAccessException {
        super.registerNode(array, n, snmpMibNode);
        if (n < 0) {
            return;
        }
        if (n >= array.length) {
            return;
        }
        this.registerNestedArc(array[n]);
        return;
    }
    
    @Override
    void findHandlingNode(SnmpVarBind snmpVarBind, long[] array, int n, SnmpRequestTree snmpRequestTree) throws SnmpStatusException {
        int length = array.length;
        if (snmpRequestTree == null) {
            throw new SnmpStatusException(5);
        }
        Object userData = snmpRequestTree.getUserData();
        if (n >= length) {
            throw new SnmpStatusException(6);
        }
        long n2 = array[n];
        if (this.isNestedArc(n2)) {
            super.findHandlingNode(snmpVarBind, array, n, snmpRequestTree);
        }
        else if (this.isTable(n2)) {
            this.getTable(n2).findHandlingNode(snmpVarBind, array, n + 1, snmpRequestTree);
        }
        else {
            this.validateVarId(n2, userData);
            if (n + 2 > length) {
                throw new SnmpStatusException(224);
            }
            if (n + 2 < length) {
                throw new SnmpStatusException(224);
            }
            if (array[n + 1] != 0L) {
                throw new SnmpStatusException(224);
            }
            snmpRequestTree.add(this, n, snmpVarBind);
        }
        return;
    }
    
    @Override
    long[] findNextHandlingNode(SnmpVarBind snmpVarBind, long[] array, int n, int n2, SnmpRequestTree snmpRequestTree, AcmChecker acmChecker) throws SnmpStatusException {
        int length = array.length;
        if (snmpRequestTree == null) {
            throw new SnmpStatusException(225);
        }
        Object userData = snmpRequestTree.getUserData();
        int requestPduVersion = snmpRequestTree.getRequestPduVersion();
        if (n >= length) {
            return super.findNextHandlingNode(snmpVarBind, array, n, n2, snmpRequestTree, acmChecker);
        }
        long n3 = array[n];
        long[] nextHandlingNode = null;
        try {
            if (this.isTable(n3)) {
                SnmpMibTable table = this.getTable(n3);
                acmChecker.add(n2, n3);
                try {
                    nextHandlingNode = table.findNextHandlingNode(snmpVarBind, array, n + 1, n2 + 1, snmpRequestTree, acmChecker);
                }
                catch (SnmpStatusException ex2) {
                    throw new SnmpStatusException(225);
                }
                finally {
                    acmChecker.remove(n2);
                }
                nextHandlingNode[n2] = n3;
                return nextHandlingNode;
            }
            if (this.isReadable(n3)) {
                if (n == length - 1) {
                    long[] array2 = new long[n2 + 2];
                    array2[n2 + 1] = 0L;
                    array2[n2] = n3;
                    acmChecker.add(n2, array2, n2, 2);
                    try {
                        acmChecker.checkCurrentOid();
                    }
                    catch (SnmpStatusException ex) {
                        throw new SnmpStatusException(225);
                    }
                    finally {
                        acmChecker.remove(n2, 2);
                    }
                    snmpRequestTree.add(this, n2, snmpVarBind);
                    return array2;
                }
            }
            else if (this.isNestedArc(n3)) {
                SnmpMibNode child = this.getChild(n3);
                if (child != null) {
                    acmChecker.add(n2, n3);
                    try {
                        long[] nextHandlingNode2 = child.findNextHandlingNode(snmpVarBind, array, n + 1, n2 + 1, snmpRequestTree, acmChecker);
                        nextHandlingNode2[n2] = n3;
                        return nextHandlingNode2;
                    }
                    finally {
                        acmChecker.remove(n2);
                    }
                }
            }
            throw new SnmpStatusException(225);
        }
        catch (SnmpStatusException ex3) {
            return this.findNextHandlingNode(snmpVarBind, new long[] { this.getNextVarId(n3, userData, requestPduVersion) }, 0, n2, snmpRequestTree, acmChecker);
        }
    }
}
